# YASARA MOVIE
# TOPIC:    5. Research topics
# TITLE:    5.1. PhD Thesis Defence 2004/09/27 by Elmar Krieger
# REQUIRES: Dynamics 20.5.1
# AUTHOR:   Elmar Krieger
# LICENSE:  GPL

if Help
  Button='ContinueButton'
else
  Button='LeftButton'

# Timings:
# Title 1:30
# Molecular graphics: 2:00  
# Force fields: 1:45
# Projects: 4:30
  
RequireVersion 20.5.1
# Change working directory to the place of this macro
# (so that we don't have to specify paths when loading stuff).
CD (MacroDir)
CoordSys Left
Projection perspective
Console Off
StickRadius 70
BallStickRadius 50,70
LabelPar Color=Black
SurfPar molecular=Gaussian
ColorBG 2020ff,White
HUD Off
Menu off
ScreenSize 1024,768
LightSource 45,45,Ambience=0,Shadow=40
AtomSize 100
SurfPar Resolution=3
jpsteps=100
Fog 60
UserInput Off
fontdepthcol2='000080'
ColorBonds Grey
Boundary Wall

#
# Title Page
#
TitlePage:
Clear

if Help
  ShowMessage "With the permission of the Council of Deans and in order to obtain the degree of doctor... <LeftButton>"

# Load scene and background
LoadSce island
DelObj SimCell
for image in 'islandbg','babsi','sign'
  LoadPNG (image)
ShowImage islandbg
ColorFog b06464
Fog 100

# Create the floating buoy
ShowSphere 10,Grey
ShowArrow Start=Point,0,-15,50,End=Point,0,15,50,Radius=1,Heads=0,Color=606060
ShowBox Width=20,Height=20,Depth=2,LeftCol=c0c0c0,FrontCol=None
MoveMesh Box,Y=25
MakeImageObj Sign,sign,20,20
MakeImageObj Babsi,babsi,20,20
MoveMesh Sign Babsi,Y=25,Z=-0.5
RotateObj Babsi,Y=180
SwitchObj Babsi,off
buoy='Box Arrow Sphere Sign Babsi'
MoveObj (buoy),-19,-23,23
Wait 1
# Take snapshot here, Eliza!

# Animate the scene
jumps=6
jumpsteps=20
jumpstart=100
jumpend=jumpstart+jumps*jumpsteps
startpos='24.15,8.21,72'
startori='0,21.27,0'
phase=0.
done=0
while 1
  for i=1 to 800
    phase=(phase+2.5)%360
    # Animate the HOH waves
    # This was too slow on the 1GHz Pentium 3 laptop used for the presentation
    # and was therefore hardcoded in the undocumented AnimateWaves command
    #for j=40 to 200 step 20
    #  MoveAtom globalZ>(j) globalZ<(j+20) Obj Water,Y=(sin (phase+j*2)*0.2)
    AnimateWaves (phase) 
    # Animate the buoy
    MoveObj (buoy),Y=(sin (phase+100)*0.3)
    OriObj (buoy),Gamma=(sin phase*10)
    if i>300 and i<=350
      # Let Yami blink with the eyes
      Distance CD? CE? CZ Res 17 30,HD? HE? HZ Res 17 30 Obj Yami,bound=Yes,set=(1.+0.4*(i%5))
    else
      # Rotate Yami's antennas
      Dihedral N Res Lys,CA Res Lys,CB Res Lys,CG Res Lys Obj Yami,bound=Yes,set=(((phase*2)%360)-180)
    # Let Yami jump from time to time
    if i==jumpstart-5
      AutoPosOriObj yami,21.4,11.5,72,-16.69,-1.72,-28.31,Steps=5,Wait=No
    elif i==jumpend
      AutoPosOriObj yami,(startpos),(startori),Steps=5,Wait=No
    elif i>=jumpstart and i<jumpend
      step=(i-jumpstart)%jumpsteps
      PosObj yami,21.4,(sin (180.*step/jumpsteps)*10+11.5),72
      RotateObj yami,Y=(360./(jumps*jumpsteps))
    if LeftButton
      done=1
    if (phase==0 or phase==180) and done
      # Quit only if buoy is straight
      break 2
    Wait 1

if Help
  ShowMessage "...from the Radbound University Nijmegen, I would like to defend in public my doctoral thesis entitled as above."
  Wait (Button)
  ShowMessage "I think there is no doubt that life is a miracle. So let's look at its best invention."

# Zoom in on Babsi
x,y,z=PosObj Sign
steps=100
AutoMove ((0.-x)/steps),((-25.-y)/steps),((65.-z)/steps)
Wait (steps)
AutoMove 0,0,-0.1
AutoRotateObj (buoy),Y=1.5
SwitchObj Babsi,on
Wait 120
AutoMove 0,0,0
AutoRotateObj (buoy),Y=0
x,y,z=PosObj Sign
steps=200
AutoMove ((-0.471e0-x)/steps),((-23.894e0-y)/steps),((2.108e0-z)/steps)
Wait (steps)
AutoMove 0,0,0
# Flip to image instead of image object
DelAll
DelImage !babsi
if Help
  ShowMessage "And particularily the sense of hearing. Soundwaves reach the eardrum (1) and get transmitted to the inner ear..."
# Zoom in on the inner ear
LoadPNG ear
# TopLeft: 184,305  BottomRight: 891,832 (707x527)
ColorBG f9bd80
ShowImage babsi,184,305,(891-184),(832-305),Alpha=100,Priority=1
ShowImage ear,-700,-270,1414,1060
AutoMoveImage babsi,535,440,256,192,Alpha=40,Steps=200
AutoMoveImage ear,0,19,512,384,Steps=200
Wait 200
AutoMoveImage babsi,535,440,256,192,Alpha=0,Steps=30
Wait 30
DelImage babsi
if Help
  Wait (Button)
  ShowMessage "...via the three smallest bones in the human body (2,3,4)."
LightSource Shadow=0  
Wait (Button)

# Show the ductus cochlearis
if Help
  ShowMessage "Inside the Cochlea (8), hair cells are sitting on the Basilar membrane, ready to detect its vibrations."
ColorBG 604020
LoadPNG canal
MakeImageObj Canal,canal,20,15
PosOriObj Canal,-130,13,534,Beta=-92
AutoMoveImage ear,123,192,20,15,Steps=200
AutoPosObj Canal,-6,0,7.78,Steps=200
AutoMoveImage ear,110,192,20,15,Alpha=0,Steps=150
AutoPosOriObj Canal,0,0,7.78,0,0,0,Steps=150
DelAll
DelImage ear
# Size: 807x540
ShowImage canal,Alpha=100,Priority=1
Wait (Button)
  
# Zoom in on hair cells
if Help
  ShowMessage "A hair cell contains between 30 and 300 stereocilia, each one about 200nm thick and up to 20 micrometers long."
LoadPNG haircell
ShowImage haircell,-14445,-6079,21708,14526,Priority=0
AutoMoveImage canal,537,226,30,20,Alpha=40,Steps=300
AutoMoveImage haircell,0,0,1024,768,Steps=300
Wait 300
AutoMoveImage canal,537,226,30,20,Alpha=0,Steps=30
Wait 30
DelImage canal

# Zoom in on actin filaments
Wait 50
AutoMoveImage haircell,657,196,20,15,Steps=450
Wait 450

if Help
  ShowMessage "Each stereocilium is supported by a paracrystalline array of hundreds of gamma-actin filaments, just 8 are shown here."
LoadSce actfibers
ColorBG Black
ColorFog Black
Fog 60
Hide
row1='9-11'
row2='12 13'
row3='14-16'
ColorSurfObj (row1),molecular,OutAlpha=100,InAlpha=100
ColorSurfObj (row2),molecular,OutAlpha=50,InAlpha=100
ColorSurfObj (row3),molecular,OutAlpha=25,InAlpha=50
Pos Y=-145
AutoMoveImage haircell,660,208,15,11,Alpha=0,Steps=150
AutoPos Y=7,Z=290,Steps=150
DelImage haircell
AutoPos X=61,Z=159,Steps=50,Wait=No
for i=1 to 25
  Wait 1
for i=50 to 100 step 2
  ColorSurfObj (row2),molecular,OutAlpha=(i),InAlpha=100
  ColorSurfObj (row3),molecular,OutAlpha=(i/2),InAlpha=(i)
  Wait 1
Wait (Button)
if Help
  ShowMessage "And if we zoom closer and closer, we finally reach a scale where lengths are measured in Angstrom (10e-10 meters)."
AutoPos X=0,Z=33,Steps=50,Wait=No
for i=1 to 25
  Wait 1
for i=50 to 100 step 2
  ColorSurfObj (row3),molecular,OutAlpha=(i),InAlpha=100
  Wait 1
AutoPos X=-5.2,Y=-0.86,Z=-35,Steps=50,Wait=No
PointPar Radius=10.00
ShowDots
for i=100 to 0 step -2
  ColorSurfObj (row3),molecular,OutAlpha=(i),InAlpha=(i)
  Wait 1
DelObj !filament
AutoRotate Y=0.5
if Help  
  ShowMessage "That's a gamma-actin protein, and honestly it does not look very charming."
  Wait (Button)
  ShowMessage "A few hundred nuclei, surrounded by a whiring cloud of electrons. Obviously we first need to dress reality for our eyes."
Wait (Button)
AutoMove Y=-5
Wait 100


#
# Molecular Graphics
#
MolecularGraphics:
Clear
ColorBG Black
ColorFog Black
BuildText Font=Arial,Height=21,Spacing=1,Text="Molecular Graphics"
LightSource Shadow=0  
Fog 0
SurfPar Resolution=3
ShowDots
Hide
if Help
  ShowMessage "The only problem: today's computers are heavily optimized for drawing flat triangles and not much else."
PosObj 1,Y=-26,Z=25
AutoPosObj 1,Y=80,Z=275,Steps=100
Wait 50
for i=-140 to 140 step 4
  ShowSurfAtom GlobalX<(i),Molecular,OutCol=c0c040,OutAlpha=100
  Wait 1
LoadPNG molgra
ShowImage molgra,Alpha=0
AutoMoveImage molgra,Alpha=100,Steps=50
Wait 50
Del
Wait (Button)
if Help  
  ShowMessage "So every atom has to be built up from triangles. 20 is a joke, 80 still look ugly and only 320 triangles look roughly OK."
# Show the atom spheres
for i=0 to 2
  sphere=ShowSphere 10,Red,Level=(i)
  PosObj (sphere),Y=-15,Z=-5
  AutoRotateObj (sphere),Y=1
  AutoPosObj (sphere),((i-1)*23),-5,70,Steps=100
  Wait (Button)
# Show water
if Help  
  ShowMessage "This means that 960 triangles are required to draw a single water molecule. For large proteins this approach is far too slow."
for image in 'watergrida','watergridb','pvl','yanaconda'
  LoadPNG (image)
cenpos='-215,0,1280,960'
#AnimateImage watergrida pvl yanaconda,BlendLeft,100000,Drop,100
ShowImage watergrida,(cenpos),Alpha=0,Priority=1
AutoMoveImage watergrida,(cenpos),Alpha=100,Steps=30
Wait 30
Wait (Button)
ShowImage watergridb,(cenpos),Alpha=100,Priority=1
AnimateImage watergridb,BlendLeft,1000000,BlendLeft,100
if Help  
  ShowMessage "It was about two years of work to develop a solution: atoms are drawn with minimally 2 triangles..."
  Wait (Button)
  ShowMessage "...that do not have a single color, but instead carry the precalculated ray-traced image of an atom."
Wait 100
DelImage watergrida
Wait (Button)
AutoMoveImage watergridb,-855,-960,2560,1920,Steps=100
Wait 100
if Help  
  ShowMessage "This algorithm is quite CPU intensive, and a new programming language, PVL, was required to run it fast enough."
ShowImage pvl,(cenpos),Alpha=0,Priority=1
AutoMoveImage pvl,(cenpos),Alpha=100,Steps=30
Wait 30
Wait (Button)
AutoMoveImage pvl,0,-960,2560,1920,Steps=100
Wait 100
if Help  
  ShowMessage "Finally, a second high-level programming language, Yanaconda, completes the basis on which YASARA is built."
ShowImage yanaconda,(cenpos),Alpha=0,Priority=1
AutoMoveImage yanaconda,(cenpos),Alpha=100,Steps=30
Wait 30
Wait (Button)
AutoMoveImage yanaconda,-1710,-960,2560,1920,Steps=100
Wait 100
Wait (Button)
AnimateImage 3-5,Pop,1000000,Drop,Steps=100
LoadPNG website
ShowImage website,0,0,1024,768,Alpha=100,Priority=1
AnimateImage website,Enter=Jump,1000000,Leave=Drop,200
Wait 200
if Help  
  ShowMessage "YASARA is a molecular graphics, modeling and simulation program, together with Gert's WHAT IF the main tool in this thesis."
steps=600
AutoMoveImage website,0,(steps),1024,768,Steps=(steps)
Wait (steps)
if Help  
  ShowMessage "And by the way, everything you see on screen here is a Yanaconda program executed by YASARA."
AutoMoveImage website,0,230,1024,768,Steps=(steps-230)
Wait (steps-230)
Wait (Button)
if Help  
  ShowMessage "Being able to look at a protein in a more intuitive way..."
# Load Actin again
DelAll
DelImage 1
LoadSce actin
AutoMoveImage website,0,230,1024,768,Alpha=0,Steps=200
for i=3 to 5
  UnrestImage (i)
  Wait 50
LightSource Shadow=40
  
#Clear
#LoadSce actin
#UserInput On  

range=35.
size=1
Style Ball
BallStickAtom GlobalY>-(range/3) GlobalY<(range/3)
StickAtom GlobalY<-(range/3)
Hide
LoadPNG styles
ShowImage styles,Priority=1
AnimateImage styles,BlendTop,1000000,BlendBottom,Steps=75

# Show various graphics styles
for i=range to -range step -size
  HideDotsAtom GlobalY>(i)
  ShowAtom GlobalY>(i)
  Wait 1
for i=00 to 99 step 2
  ColorBG 0000(00+i*0.6),(i)(i)(i)
  Wait 1

Wait (Button)
UnrestImage styles

if Help  
  ShowMessage "...and at a higher abstraction level that indicates only the secondary structure, we can finally start asking scientific questions."

for i=range to -range step -size
  ShowSecRes GlobalY>(i)
  HideAtom GlobalY>(i)
  Wait 1
Wait (Button)

# Examine the Actin mutation
if Help
  ShowMessage "One such question was raised by Erwin van Wijk and Hannie Kremer at the Department of Human Genetics."
DelImage All
LoadPNG jp1ref
refpos='0,(-768+84),1024,768'
ShowImage jp1ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp1ref,(refpos),Alpha=80,Steps=100
AutoRotate 0,0,0
AutoPosOriObj 7,-3.3,8.7,-8.8,166.3,245.3,12.2,Steps=100

for i=273 to 284
  ShowSecRes (i),Ribbon
  if i==278
    ShowAtom Sidechain CA Res (i)
    StickAtom Sidechain CA Res (i)
    LabelRes (i),Format=RES,Height=0.8,X=2,Y=-2.5
  ColorAtom Backbone Res (i),320
  Wait 3
Wait (Button)
if Help
  ShowMessage "They had a patient with autosomal dominant hearing loss and found a mutation of Thr 278 to Ile.The question was:what happens?"
SwapRes 278,Ile
StickRes 278
Wait (Button)

for i=308 to 321
  ShowSecRes (i),Ribbon
  if i==313
    ShowAtom Sidechain CA Res (i)
    StickAtom Sidechain CA Res (i)
    LabelRes (i),Format=RES,Height=0.8,X=-2.3,Y=2.5
  ColorAtom Backbone Res (i),320
  Wait 3

ShowArrow AtAtom,2050,AtAtom,2318,Color=Yellow
LabelDis 2050,2318,Format=DIS,Height=0.5,X=1
if Help
  ShowMessage "There is a Met close by, and the mutant Ile heavily bumps into it. This is physically not possible, so something has to move."
Clean
HideAtom Element H
Cell 40,30,30
PosObj SimCell,Z=5
SwitchObj SimCell,off
Wait (Button) 
AutoMoveImage jp1ref,(refpos),Alpha=0,Steps=100
if Help
  ShowMessage "To find out what, we can run a molecular dynamics simulation and let the computer predict how the system evolves over time."
# Simulate the mutant
TempCtrl SteepDes
ForceField Yamber2
Cutoff 5.24
Sim On
Wait SpeedMax<3000
Temp 298K
TempCtrl Rescale
Wait (Button)
if Help
  ShowMessage "That's nice. But for the sake of clean science, we must of course apply the same procedure also to the wild-type protein."
  
# Show plot for wild-type simulations
imgpos='X=-256,Y=-300,Width=(1024+512),Height=(768+384)'
DelImage all
MakeTextObj results,Width=100,Height=1.3
Font Name=Arial,Height=100%,Color=White,Spacing=2,Depth=0.3,DepthCol=(fontdepthcol2)
FontFog off
PosText 50%,0%,Justify=Center
Print "And the wild-type ?"
PosObj results,Y=10,Z=4.7
AutoPosObj results,Y=4.7,Steps=100,Wait=No
LoadPNG figure1a
LoadPNG figure1b
ShowImage figure1a,(imgpos),Alpha=0,Priority=1
AutoMoveImage figure1a,(imgpos),Alpha=100,Steps=50
Wait (Button)  
ShowImage figure1b,(imgpos),Alpha=100,Priority=1
AnimateImage figure1b,Enter=BlendLeft,Rest=100000,Steps=200
if Help
  ShowMessage "And then it unfortunately turns out that we also find significant movements in wild-type proteins."
Wait (Button)
LoadPNG how
ShowImage how,256,192,512,384,Alpha=0,Priority=1
AutoMoveImage how,Alpha=100,Steps=50
Wait 55
LoadPNG forcefield
ShowImage forcefield,Alpha=100,Priority=1
SwapImage forcefield,how
Wait (Button)
if Help
  ShowMessage "That's what we did using a new approach that finds the optimum set of parameters for a given energy function."
AutoMoveImage how,Alpha=0,Steps=50
Wait 50
DelImage how
Wait (Button)
AutoMoveImage forcefield,Alpha=0,Steps=50
Wait 50
DelImage forcefield
LoadPNG figure1c
LoadPNG yamberref
if Help
  ShowMessage "The resulting YAMBER force field stays closer to the allowed region, and I'm confident that its follow up will be 100% green."
ShowImage figure1c,(imgpos),Alpha=100,Priority=1
ShowImage yamberref,X=0,Y=(-768+56),1024,768,Alpha=0,Priority=1
AnimateImage figure1c,Enter=BlendLeft,Rest=100000,Steps=200
AutoMoveImage yamberref,X=0,Y=(-768+56),1024,768,Alpha=100
Wait 200
Wait (Button)  

#
# The last mile
#
LastMile:
Clear
LightSource Shadow=40
MakeTextObj results,Width=500,Height=8
Font Name=Arial,Height=30%,Color=White,Spacing=2,Depth=4,DepthCol=(fontdepthcol2)
FontFog off
PosText 50%,70%,Justify=Center
Print "Can we predict mutants ="
PosText 50%,10%,Justify=Center
Print "improve homology models?"
PosObj results,Y=45,Z=41
MakeTextObj mile,Width=500,Height=3
Font Name=Arial,Height=100%,Color=4040ff,Depth=1
PosText 50%,0%,Justify=Center
Print "The last mile of the protein folding problem"
PosObj mile,Y=-45,Z=84
AutoPosObj results,Y=14.3,Steps=100,Wait=No
AutoPosObj mile,Y=-28,Steps=100,Wait=No
LoadPNG yamberref
ShowImage yamberref,X=0,Y=(-768+56),1024,768,Alpha=100,Priority=1
LoadPNG figure2
if Help
  ShowMessage "Keeping in mind that protein structure prediction by homology modeling is the same as making lots of mutations..."
Wait (Button)
ShowImage figure2,X=-128,Y=(-134-96-32),Width=(1024+256),Height=(768+192),Alpha=0,Priority=1
AutoMoveImage figure2,X=-128,Y=(-134-96-32),Width=(1024+256),Height=(768+192),Alpha=100,Steps=100
if Help  
  ShowMessage "YAMBER also does a better job there, being often able to heavily improve models during a simulation."
Wait 100
Wait (Button)  
if Help  
  ShowMessage "Unfortunately there is no guarantee and models equally often go in the wrong direction. So we run 100 parallel simulations..."
AutoMoveImage figure2,X=-1024,Y=(-134-768),Width=(1024*3),Height=(768*3),Alpha=0,Steps=50
AutoMoveImage yamberref,X=0,Y=(-768+56),1024,768,Alpha=0,Steps=50
Wait 51
Wait 1
DelImage All
for i=1 to 5
  LoadPNG md101,TransCol=Black
  ShowImage (i),448,336,128,96,Alpha=100,Priority=1
LoadPNG modelsref
ShowImage modelsref,0,(-768+56),1024,768,Alpha=100,Priority=1
for i=1 to 5
  AutoMoveImage (i),-1024,-768,(1024*3),(768*3),Alpha=100,Steps=500
  Wait 40
Wait 350
AutoMoveImage modelsref,0,(-768+56),1024,768,Alpha=0,Steps=50
Wait 50
LoadPNG figure3
if Help  
  ShowMessage "and then use a higher level energy function to analyze them and pick out the best model. That's iterated many times."
ShowImage figure3,X=256,Y=192,Width=512,Height=384,Alpha=0,Priority=1
AutoMoveImage figure3,X=-256,Y=-300,Width=(1024+512),Height=(768+384),Alpha=100,Steps=100
AutoPosObj mile,Y=-33,Steps=100,Wait=No
Wait 100
Wait (Button)  

#
# Collaboration projects
#
Collaborations:
Clear
Fog 60
LoadPNG sky
ShowImage sky
if Help
  ShowMessage "Of course all these energy functions are useless unless they are applied to questions of practical interest."
  Wait (Button)
  ShowMessage "And that's where I relied on joint projects with colleagues in experimental research groups."
BuildText Font=Arial,Height=21,Spacing=1,Text="Joint"
BuildText Font=Arial,Height=21,Spacing=1,Text="Projects"
ShowSurf molecular,OutCol=FFA040,OutAlpha=100
Hide
ColorBG 0000ff,White
Pos Z=109
Wait 50
AutoPosObj 1,Y=18,Z=350,Steps=100,Wait=No
AutoPosObj 2,Y=-18,Z=350,Steps=100,Wait=Yes
#SaveBMP jp1bg
Wait (Button)

#
# Actin
#
Actin:
Clear   
ColorBG 000060,White
LoadSce jp1
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="Actin"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
LoadPNG jp1ref
refpos='0,(-768+84),1024,768'
ShowImage jp1ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp1ref,(refpos),Alpha=80,Steps=100
SwapRes 278,Thr
ShowAtom Sidechain CA Res 278
if Help  
  ShowMessage "I already talked about the mutation in gamma-actin causing hearing loss."
Wait (Button)
SwapRes 278,Ile
ShowAtom Sidechain CA Res 278
ShowArrow AtAtom,2050,AtAtom,2318,Color=Yellow
Wait (Button)
if Help  
  ShowMessage "Functionally, actin is often tightly coupled to another famous protein investigated by Mirijam Luijendijk:"
ShowSec Ribbon
ColorRes not 278 313,blue,cyan
ColorAtom CA Res 272-285 307-322 SecStr Helix,320
AutoMoveImage jp1ref,(refpos),Alpha=0,Steps=(jpsteps)
AutoPosOriObj 1,0,0,77,87,218,9,Steps=(jpsteps)
#SaveBMP jp1fg
LoadPNG jp1bg
LoadPNG jp1fg
ShowImage jp1bg
ShowImage jp1fg,Priority=1
AutoMoveImage jp1fg,0,0,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)

#
# Myosin   
#
Myosin:
Clear
ColorBG 004060,White
Style Stick
LoadSce jp2
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="Myosin"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
LoadPNG jp2ref
refpos='0,(-768+140),1024,768'
ShowImage jp2ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp2ref,(refpos),Alpha=80,Steps=100
LabelPar Color=Black
UnlabelRes 454
HideAtom Sidechain Res 454
HideAtom Element H with bond to Element C
if Help  
  ShowMessage "Myosin. Even though there is no muscle contraction in the inner ear, myosin is doing transportation work there."
  Wait (Button)
  ShowMessage "One key residue is Asn 458 which connects the switch II loop with a helix in the C-terminal part."
Wait (Button)
if Help  
  ShowMessage "A mutation to Ile distorts the loop, which mediates the power stroke and is involved in ATP binding. This also impairs hearing."
SwapRes 458,Ile
#Dihedral 7201,7206,7208,7215,Set=-60
Dihedral 7202,7206,7208,7215,Set=-60
ShowArrow AtAtom,7208,AtAtom,6930,Color=Yellow
ShowArrow AtAtom,7215,AtAtom,6911,Color=Yellow
DelAtom Element H and not Res 439,Center=Yes
Wait (Button)
AutoMoveImage jp2ref,(refpos),Alpha=0,Steps=(jpsteps)
AutoPosOriObj 1,-30,-7,190,3,213,-53,Steps=(jpsteps)
ColorRes Obj 1,blue,cyan
#SaveBMP jp2fg
LoadPNG jp2bg
LoadPNG jp2fg
ShowImage jp2bg  
ShowImage jp2fg,Priority=1
AutoMoveImage jp2fg,-1024,0,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)

#
# ATPase 
#
ATPase:
Clear
ColorBG 006040,White
Style Stick
LoadSce jp3
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="H,K-ATPase"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
LoadPNG jp3ref
refpos='0,(-768+84),1024,768'
ShowImage jp3ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp3ref,(refpos),Alpha=80,Steps=100
if Help  
  ShowMessage "Another fascinating protein is studied by Jan Koenderink and Jan Joep de Pont at the Department of Biochemistry:"
  Wait (Button)
  ShowMessage "Gastric H,K-ATPase, a membrane ion pump making sure that our stomach is acidic."
  Wait (Button)
  ShowMessage "This is the predicted potassium binding site with a characteristic salt-bridge."
Wait (Button)
LoadSce jp3b
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="H,K-ATPase"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
if Help  
  ShowMessage "If Glu 820 is mutated to Gln, Lys 791 seems to mimic the potassium ion, explaining the mutant's potassium-independent activity."
Wait (Button)
ShowSec Cartoon
AutoMoveImage jp3ref,(refpos),Alpha=0,Steps=(jpsteps)
AutoPosOriObj 1,-25,-13,134,68,4,-52,Steps=(jpsteps)
ColorRes Obj 1,blue,cyan
ShowSec Ribbon
#SaveBMP jp3fg
LoadPNG jp3bg
LoadPNG jp3fg
ShowImage jp3bg  
ShowImage jp3fg,Priority=1
AutoMoveImage jp3fg,-2048,0,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)

#
# DJ-1
#
DJ1:
Clear
ColorBG 006000,White
Style Stick
LoadSce jp4
LoadPNG jp4ref
refpos='0,(-768+195),1024,768'
ShowImage jp4ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp4ref,(refpos),Alpha=80,Steps=100
PosObj 1,9.4,4.6,20.4
if Help
  ShowMessage "That's a model of the DJ-1 protein, which is suspected to be involved in oxidative stress response in the brain."
  Wait (Button)
  ShowMessage "Vincenzo Bonifati at the EMC Rotterdam discovered that a mutation of Leucine 166 is coupled to early onset Parkinsonism."
Wait (Button)
if Help
  ShowMessage "When mutated to Pro, the C-terminal helix which supports an active site loop is strongly destabilized."
SwapRes 166,Pro
ShowAtom Res 166 and not C O
StickRes 166
Wait 1
Clean
HideAtom Element H
Cell Auto
SwitchObj SimCell,off
ForceField Yamber2
Cutoff 5.24
TempCtrl SteepDes
Sim On
Wait SpeedMax<3000
TempCtrl Anneal
TimeStep 2,1
Wait 100
Wait (Button)
if Help
  ShowMessage "So a lack of response to brain cell damage caused by free radicals may well be one molecular basis of Parkinsonism."
DelObj SimCell
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="DJ-1"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
AutoMoveImage jp4ref,(refpos),Alpha=0,Steps=(jpsteps)
AutoPosOriObj 1,0,-3,45,15,354,-11,Steps=(jpsteps)
ColorRes Obj 1,blue,cyan
ShowSec Ribbon
#SaveBMP jp4fg
LoadPNG jp4bg
LoadPNG jp4fg
ShowImage jp4bg  
ShowImage jp4fg,Priority=1
AutoMoveImage jp4fg,-2048,-768,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)

#
# Pex5p
#
Pex5p:
Clear
ColorBG 406000,White
Style Stick
LoadSce jp5
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="Pex5p"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
LoadPNG jp5ref
refpos='0,(-768+84),1024,768'
ShowImage jp5ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp5ref,(refpos),Alpha=80,Steps=100
if Help
  ShowMessage "The group of Ida van der Klei in Groningen is interested in the passage of proteins to the peroxisome."
  Wait (Button)
  ShowMessage "This is a model of the transport protein Pex5p, and the bound ligand is the signal peptide, marked with a dansyl cap."
Wait (Button)
for i=5 to 1 step -1
  LabelRes (i) Mol D,RESName RESNUM,Height=1.5
  Wait 30
if Help
  ShowMessage "With fluorescence spectroscopy they measured an energy transfer between the cap and the closest Trp matching the model."
Wait (Button)
ShowArrow AtAtom,2488,AtAtom,1575,Color=Blue
#Wait 30
#ShowArrow AtAtom,2486,AtAtom,885,Color=Blue
#Wait 30
#ShowArrow AtAtom,2484,AtAtom,447,Color=Blue
Wait (Button)
AutoMoveImage jp5ref,(refpos),Alpha=0,Steps=(jpsteps)
AutoPosOriObj 1,-3.5,-6,68,-51,72,-15,Steps=(jpsteps)
ColorRes Obj 1,blue,cyan
ShowSec Ribbon
#SaveBMP jp5fg
LoadPNG jp5bg
LoadPNG jp5fg
ShowImage jp5bg  
ShowImage jp5fg,Priority=1
AutoMoveImage jp5fg,-2048,-1536,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)

#
# FGF14
#
FGF14:
Clear
ColorBG 604000,White
Style Stick
LoadSce jp6
LabelPar Color=800000
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="FGF 14"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
LoadPNG jp6ref
refpos='0,(-768+112),1024,768'
ShowImage jp6ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp6ref,(refpos),Alpha=80,Steps=100
if Help
  ShowMessage "Another pathologic mutation discovered at the EMC Rotterdam is in FGF14, a protein involved in neural development."
Wait (Button)
ShowSurfObj 1,molecular,OutCol=2060ff,OutAlpha=50,InCol=808080,InAlpha=100
if Help
  ShowMessage "If a phenylalanine in the hydrophobic core is mutated to serine..."
Wait (Button)
AutoPosObj 1,2,0,10,Steps=150
SwitchObj 2,Off
Wait (Button)
SwapRes 145,Ser
if Help
  ShowMessage "...that leaves a big hole which is very destabilizing and may well explain the observed neurodegeneration."
Wait (Button)
AutoRotateObj 1,Y=0.5
LoadPNG jp6bg
LoadPNG jp6fg
Wait (Button)
AutoRotateObj 1,Y=0
SwitchObj 2,On
AutoMoveImage jp6ref,(refpos),Alpha=0,Steps=(jpsteps)
AutoPosOriObj 1,0,-3.2,44,-88,65,39,Steps=(jpsteps)
LabelPar Color=Black
for i=30 to -30 step -2
  HideSurfAtom GlobalY>(i) Obj 1
  Wait 1
ColorRes Obj 1,blue,cyan
ShowSec Ribbon
#SaveBMP jp6fg
ShowImage jp6bg  
ShowImage jp6fg,Priority=1
AutoMoveImage jp6fg,-1024,-1536,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)


#
# p63
#
p63:
Clear
ColorBG 600000,White
Style Stick
LoadSce jp7
NumberRes 224,298
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="p63"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
LoadPNG jp7ref
refpos='0,(-768+84),1024,768'
ShowImage jp7ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp7ref,(refpos),Alpha=80,Steps=100
if Help
  ShowMessage "A very special mutation in p63 causing ADULT syndrome was discovered by Pascal Duijf in the Department of Human Genetics."
Wait (Button)
if Help
  ShowMessage "While all other previously known mutations directly affected DNA binding with obvious consequences..."
ShowRes Arg Lys with distance<6 from NucAcid
BallStickRes Protein
HideAtom !CA Protein Backbone 
Wait (Button)
if Help
  ShowMessage "...this one is at a remote site and even leads of an activation of transcription. The mechanism is still unknown."
AutoPosObj 1,-3,-8,74,Steps=150
Wait (Button)
SwapRes 298,Gln
BallStickRes Protein
ShowAtom SideChain CA Res 298
Wait (Button)
ColorRes Protein Obj 1,blue,cyan
AutoMoveImage jp7ref,(refpos),Alpha=0,Steps=(jpsteps)
Wait (jpsteps)
#SaveBMP jp7fg
LoadPNG jp7bg
LoadPNG jp7fg
ShowImage jp7bg  
ShowImage jp7fg,Priority=1
AutoMoveImage jp7fg,0,-1536,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)

#
# IL8+Heparin
#
IL8Heparin:
Clear
ColorBG 600060,White
LoadSce jp8
SplitObj 1
HideAtom Element H
Pos 7,2.5,32
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="IL8-Heparin"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
LoadPNG jp8ref
refpos='0,(-768+84),1024,768'
ShowImage jp8ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp8ref,(refpos),Alpha=80,Steps=100
SwitchObj 1,off
HideRes 505-523
PosObj 3,-20,10,22.7
if Help
  ShowMessage "Together with Andreas Kungl at the University of Graz, I docked the chemokine Interleukin-8 with..."
Wait (Button)
AutoPosObj 3,4.8,10.3,22.7,Steps=150
if Help
  ShowMessage "...the anionic polysaccharide heparin. Inhibiting this interaction would help to stop inflammatory reactions."
Wait (Button)
JoinObj 2 3,1
SwitchObj 1,On
HideSecMol A
AutoPosObj 1,0,-9.5,78,Steps=150
Wait 50
ShowSecMol A,Ribbon
if Help
  ShowMessage "The topic is complicated by the fact that Interleukin-8 dimerizes and long stretches of heparin bind particularily well."
Wait (Button)
for i=505 to 523
  ShowAtom Res (i) Element !H
  Wait 5
Wait (Button)
if Help
  ShowMessage "Modeling suggested that a central disaccharide motif is sufficient for binding, and this could be validated experimentally."
ColorRes Protein Obj 1,blue,cyan
AutoMoveImage jp8ref,(refpos),Alpha=0,Steps=(jpsteps)
Wait (jpsteps)
#SaveBMP jp8fg
LoadPNG jp8bg
LoadPNG jp8fg
ShowImage jp8bg  
ShowImage jp8fg,Priority=1
AutoMoveImage jp8fg,0,-768,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)

#
# DC-SIGN
#
DCSign:
Clear
ColorBG 606060,White
LoadSce jp9
obj=BuildText Font=Arial,Height=21,Spacing=1,Text="DC-SIGN"
ShowSurfObj (obj),molecular,OutCol=FFA040,OutAlpha=100
HideObj (obj)
PosObj (obj),Y=55,Z=180
LoadPNG jp9ref
refpos='0,(-768+84),1024,768'
ShowImage jp9ref,(refpos),Alpha=0,Priority=1
AutoMoveImage jp9ref,(refpos),Alpha=80,Steps=100
MoveObj 11,X=-20
if Help
  ShowMessage "Finally, DC-SIGN, the receptor protein for HIV on dendritic cells investigated by Theo Geijtenbeek at VUMC Amsterdam."
Wait (Button)
if Help
  ShowMessage "The protein has a sugar binding site involving Calcium ions, and as the HIV target protein gp120 is heavily glycosylated..."
AutoPosObj 11,X=-10.4,Steps=100
Wait (Button)
if Help  
  ShowMessage "it was expected to bind there. Suprisingly, gp120 also binds without glycosylation, so we are now searching its binding site."
JoinObj 11 16,1
AutoMoveImage jp9ref,(refpos),Alpha=0,Steps=100
AutoPosObj 1,0,-6.8,51,Steps=100
ColorRes Protein Obj 1,blue,cyan
Wait (jpsteps)
#SaveBMP jp9fg
LoadPNG jp9bg
LoadPNG jp9fg
ShowImage jp9bg  
ShowImage jp9fg,Priority=1
AutoMoveImage jp9fg,-1024,-768,3072,2304,Steps=(jpsteps)
Del
Wait (jpsteps)
Wait (Button)

#
# Thanksgiving
#
Thanksgiving:
Clear
LoadPNG thanksbg
ShowImage thanksbg
LoadPNG thanks
ShowImage thanks,384,288,256,192,Alpha=0,Priority=1
AutoMoveImage thanks,Alpha=65,Steps=100
if Help
  for text in "This thesis would of course not have been possible without the deeply appreciated help and ideas of everyone I met here.",
              "Thanks Gert for everything you did for me during the past four years to turn a freshly baked biologist into a Dr. of bioinformatics.",
              "Thanks Karin and Frank for having looked after me from the moment I arrived in what was once a foreign country till today.",
              "Thanks Marc for preserving this moment, thanks Barbara & Esther for all the time you spent on organizing this day.",
              "Thanks to Sander, Chris and everyone at the CMBI for all the help, friendship, fun and hot ideas.",
              "Thanks to everyone who got me involved in a joint-project of practical interest so that I didn't get lost in theory.",
              "And of course, biggest thanks to Babsi and my parents for their exceptional support and everything beyond.",
              "Having presented this summary of my doctoral thesis, I return the floor to the Rector."
    ShowMessage (text)
    Wait (Button)
HideMessage
Wait ContinueButton
Menu On
Stop


# Helper script to create the 100 MD snapshots
Clear
Menu Off
LoadPDB 1crn
Cell Auto,Extension=5
Clean
ForceField Yamber2
FillCellWater 
Style Cartoon
StickAtom SideChain CA or Res HOH
ShowRes HOH
ColorBG Magenta
Antialias 0
HUD Off

loop='0 to 19','19 to 0 step -1'

for i=1 to 2
  for j=(loop(i))
    Pos (((j%5)-2)*63),((-1.5+(j-j%5)/5)*62),300
    #Pos X=((j%5-2)*80),Y=(((j-j%5)/5-2)*60),Z=380
    size=FileSize bmp/snap(i).bmp
    if size
      LoadBMP snap(i)
      ShowImage snap(i),0,0,1024,768,Alpha=100
    SaveBMP snap(i),menu=No
    DelImage all



